@@ -3,6 +3,7 @@ import pandas as pd
 from collections import defaultdict
 import datetime
 import re
+import requests
 
 # 讀取新上市的權證標的
 # 從元富的網站讀取
@@ -33,7 +34,10 @@ def get_new_warrant_list():
     count_no_data = 0
 
     for i in range(1, 9999):
-        df_tmp = pd.read_html(f'https://newjust.masterlink.com.tw/z/zx/zxc/zxc.djhtm?a=2&page={i}')
+        url = f'https://newjust.masterlink.com.tw/z/zx/zxc/zxc.djhtm?a=2&page={i}'
+        # 元富把 pd.read_html() 檔掉了...，所以得用別的方式去讀取
+        ret = requests.get(url, headers={'User-agent': 'Mozilla/5.0'}).text
+        df_tmp = pd.read_html(requests.get(url, headers={'User-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_3) AppleWebKit/604.5.6 (KHTML, like Gecko) Version/11.0.3 Safari/604.5.6'}).text)
         # sleep(1)
         df_tmp = df_tmp[2].iloc[2:]
         # df_tmp.columns = df_tmp.iloc[0]
